## "Risk Appetite Scoring"

rm(list=ls())


# Libray load
library(readr)
library(ggplot2)
library(dplyr)
library(tidyr)
library(grid)
library(shiny)
library(ggthemes)

fnames <- c("Holt Laury Survey.csv")

# Read the file and convert to risk scores
dat <- read_csv(fnames)
  
dat <- dat[,2:13]
dat <- tibble::rowid_to_column(dat, "ID")
dat2 <- dat %>%
    pivot_longer(cols = 4:ncol(dat), 
                 names_to = "Question",
                 values_to = "Response") 
  
dat2$Binary <- ifelse(grepl("100", dat2$Response, ignore.case = T), "1","0") 
  
dat2$Binary <- as.numeric(dat2$Binary)
dat2 <- dat2 %>%
    mutate_at(vars(ID, 
                   Gender), 
              list(factor))
dat2 <- separate(data = dat2, col = `Indicate your domain of expertise, you can pick multiple`, 
                   into = c("Domain1", "Domain2", "Domain3"), sep = ";")
  
gender <- dat2 %>% group_by(Gender) %>%
    summarize(Score = sum(Binary)/length(Gender)*10) %>% 
    mutate_if(is.numeric, round, 0)
  
gender <- gender %>% 
    mutate(Appetite = case_when(Score == 0 ~ 'highly risk loving',
                                Score == 1 ~ 'highly risk loving',
                                Score == 2 ~ 'very risk loving',
                                Score == 3 ~ 'risk loving',
                                Score == 4 ~ 'risk neutral',
                                Score == 5 ~ 'slightly risk averse',
                                Score == 6 ~ 'risk averse',
                                Score == 7 ~ 'very risk averse',
                                Score == 8 ~ 'highly risk averse',
                                Score == 9 ~ 'stay in bed',
                                Score == 10 ~ 'stay in bed'))
  
domain <- dat2 %>% group_by(Domain1) %>%
    summarize(Score = sum(Binary)/length(Domain1)*10)%>% 
    mutate_if(is.numeric, round, 0)
  
domain <- domain  %>% 
    mutate(Appetite = case_when(Score == 0 ~ 'highly risk loving',
                                Score == 1 ~ 'highly risk loving',
                                Score == 2 ~ 'very risk loving',
                                Score == 3 ~ 'risk loving',
                                Score == 4 ~ 'risk neutral',
                                Score == 5 ~ 'slightly risk averse',
                                Score == 6 ~ 'risk averse',
                                Score == 7 ~ 'very risk averse',
                                Score == 8 ~ 'highly risk averse',
                                Score == 9 ~ 'stay in bed',
                                Score == 10 ~ 'stay in bed'))

individual <- dat2 %>% group_by(ID) %>%
  summarize(score = sum(Binary)/length(ID)*10) %>% 
  mutate_if(is.numeric, round, 0)

fulldat <- left_join(dat2, individual, by = "ID")


### Average score by Gender   

summaryDat <- fulldat %>%
  group_by(Gender) %>%
  dplyr::summarise(MeanByGender = mean(score), StdDevB = sd(score))

summaryDat

### Average score by Domain   

summaryDat <- fulldat %>%
  group_by(Domain1) %>%
  dplyr::summarise(MeanByDomain = mean(score), StdDevB = sd(score))

summaryDat


### Distribution by Domain

grob <- grobTree(textGrob("Highly Risk Loving", x=0.4,  y=0.04, hjust=0,
                            gp=gpar(col="red", fontsize=22, fontface="bold")))
grob2 <- grobTree(textGrob("Stay in Bed", x=0.45,  y=0.95, hjust=0,
                             gp=gpar(col="blue", fontsize=22, fontface="bold")))
  
ggplot(fulldat)+
    aes(x = Domain1, y = score)+
    geom_boxplot()+
    ggthemes::theme_clean()+
    xlab("")+
    ylab("Number of safe choices")+
    ylim(0,10)+
    theme(axis.text.x = element_text(size = 14),
          axis.text.y = element_text(size = 14),
          axis.title.y = element_text(size = 16))+
    annotation_custom(grob)+
    annotation_custom(grob2)


### Distribution by Gender

grob <- grobTree(textGrob("Highly Risk Loving", x=0.4,  y=0.04, hjust=0,
                            gp=gpar(col="red", fontsize=22, fontface="bold")))
grob2 <- grobTree(textGrob("Stay in Bed", x=0.45,  y=0.95, hjust=0,
                             gp=gpar(col="blue", fontsize=22, fontface="bold")))
  
ggplot(fulldat)+
    aes(x = Gender, y = score)+
    geom_boxplot()+
    ggthemes::theme_clean()+
    xlab("")+
    ylab("Number of safe choices")+
    ylim(0,10)+
    theme(axis.text.x = element_text(size = 14),
          axis.text.y = element_text(size = 14),
          axis.title.y = element_text(size = 16))+
    annotation_custom(grob)+
    annotation_custom(grob2)
  